@@ -7,12 +7,13 @@
 //! - [Miner], which stake tokens into [Quarry]s to receive rewards.
 //!
 //! This program is modeled after [Synthetix's StakingRewards.sol](https://github.com/Synthetixio/synthetix/blob/4b9b2ee09b38638de6fe1c38dbe4255a11ebed86/contracts/StakingRewards.sol).
+#![deny(rustdoc::all)]
+#![allow(rustdoc::missing_doc_code_examples)]
 
 #[macro_use]
 mod macros;
 
 use anchor_lang::prelude::*;
-use anchor_lang::Key;
 use anchor_spl::token::Token;
 use anchor_spl::token::{self, Mint, TokenAccount, Transfer};
 use payroll::Payroll;
@@ -29,7 +30,7 @@ pub mod rewarder;
 
 use crate::quarry::StakeAction;
 
-solana_program::declare_id!("QMNeHCGYnLVDn1icRAfQZpjPLBNkfGbSKRB83G5d8KB");
+declare_id!("QMNeHCGYnLVDn1icRAfQZpjPLBNkfGbSKRB83G5d8KB");
 
 /// Maximum number of tokens that can be rewarded by a [Rewarder] per year.
 pub const MAX_ANNUAL_REWARDS_RATE: u64 = u64::MAX >> 3;
@@ -399,12 +400,12 @@ pub mod quarry_mine {
     }
 }
 
-/// --------------------------------
-/// PDA Structs
-/// --------------------------------
+// --------------------------------
+// PDA Structs
+// --------------------------------
 
 /// Controls token rewards distribution to all [Quarry]s.
-/// The [Rewarder] is also the [Minter] registered to the [MintWrapper].
+/// The [Rewarder] is also the [quarry_mint_wrapper::Minter] registered to the [quarry_mint_wrapper::MintWrapper].
 #[account]
 #[derive(Copy, Default, Debug)]
 pub struct Rewarder {
@@ -843,7 +844,7 @@ pub struct ExtractFees<'info> {
     #[account(mut)]
     pub claim_fee_token_account: Account<'info, TokenAccount>,
 
-    /// [TokenAccount] owned by the [addresses::FEE_TO_ADDRESS].
+    /// [TokenAccount] owned by the [addresses::FEE_TO].
     /// Holds DAO claim fees.
     #[account(mut)]
     pub fee_to_token_account: Account<'info, TokenAccount>,
